# Merlin AI
## The AI engineering framework

This library is heavily inspired by [Marvin](https://pypi.org/project/marvin/) and gives all credits for the idea to it's authors.

It's a complete rewrite and does not depend on Pydantic, but uses Python's dataclasses and Enums instead.
